<?php

namespace Drupal\content_feedback\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Url;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Form to confirm the deletion of content feedback.
 */
class DeleteContentFeedback extends ConfirmFormBase {
  /**
   * The ID of the content feedback to delete.
   *
   * @var int
   */
  protected $id;

  /**
   * Whether the content feedback exists.
   *
   * @var bool
   */
  protected $exists;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'content_feedback_delete';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete submission %id?', ['%id' => $this->id]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }


  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('content_feedback_list.content');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $id = '') {
    $this->id = $id;

    // Check if the content feedback exists before proceeding.
    $this->exists = ContentFeedbackClass::checkFeedback($this->id);

    // If the feedback does not exist, throw a NotFoundHttpException.
    if (!$this->exists) {
      throw new NotFoundHttpException();
    }

    // Otherwise, build the form.
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Delete the content feedback entry.
    ContentFeedbackClass::deleteContentFeedback($this->id);

    // Show a confirmation message to the user.
    $this->messenger()->addMessage($this->t('Content Feedback has been deleted.'));

    // Redirect to the content feedback list page.
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
